==> fasc-openapi-java-sdk-5.4.5.0524-sources.jar: com/fasc/open/api/v5_1/res/template/SignTemplateDetailRes.java <==
package com.fasc.open.api.v5_1.res.template;

import com.fasc.open.api.bean.base.BaseBean;
import com.fasc.open.api.v5_1.req.signtask.Watermark;
import com.fasc.open.api.v5_1.req.template.ApprovalInfo;

import java.util.List;

/**
 * @author Fadada
 * 2021/9/11 15:16:27
 */
public class SignTemplateDetailRes extends BaseBean {
    private String signTemplateId;
    private String signTemplateName;
    private String businessTypeName;
    private String signTemplateStatus;
    private String certCAOrg;
    private Boolean signInOrder;
    private List<DocumentInfo> docs;
    private List<AttachInfo> attachs;
    private List<SignTaskActorInfo> actors;
    private String catalogName;
    private String creatorMemberName ;
    private String createSerialNo;
    private String storageType;
    private List<Watermark> watermarks;
    private List<ApprovalInfo> approvalInfos ;

    public String getCreatorMemberName() {
        return creatorMemberName;
    }

    public void setCreatorMemberName(String creatorMemberName) {
        this.creatorMemberName = creatorMemberName;
    }

    public List<ApprovalInfo> getApprovalInfos() {
        return approvalInfos;
    }

    public void setApprovalInfos(List<ApprovalInfo> approvalInfos) {
        this.approvalInfos = approvalInfos;
    }

    public String getBusinessTypeName() {
        return businessTypeName;
    }

    public void setBusinessTypeName(String businessTypeName) {
        this.businessTypeName = businessTypeName;
    }

    public String getSignTemplateId() {
        return signTemplateId;
    }

    public void setSignTemplateId(String signTemplateId) {
        this.signTemplateId = signTemplateId;
    }

    public String getSignTemplateName() {
        return signTemplateName;
    }

    public void setSignTemplateName(String signTemplateName) {
        this.signTemplateName = signTemplateName;
    }

    public String getSignTemplateStatus() {
        return signTemplateStatus;
    }

    public void setSignTemplateStatus(String signTemplateStatus) {
        this.signTemplateStatus = signTemplateStatus;
    }

    public List<DocumentInfo> getDocs() {
        return docs;
    }

    public void setDocs(List<DocumentInfo> docs) {
        this.docs = docs;
    }

    public Boolean getSignInOrder() {
        return signInOrder;
    }

    public void setSignInOrder(Boolean signInOrder) {
        this.signInOrder = signInOrder;
    }

    public List<SignTaskActorInfo> getActors() {
        return actors;
    }

    public void setActors(List<SignTaskActorInfo> actors) {
        this.actors = actors;
    }

    public List<AttachInfo> getAttachs() {
        return attachs;
    }

    public void setAttachs(List<AttachInfo> attachs) {
        this.attachs = attachs;
    }

    public String getCertCAOrg() {
        return certCAOrg;
    }

    public void setCertCAOrg(String certCAOrg) {
        this.certCAOrg = certCAOrg;
    }

    public String getCatalogName() {
        return catalogName;
    }

    public void setCatalogName(String catalogName) {
        this.catalogName = catalogName;
    }

    public String getCreateSerialNo() {
        return createSerialNo;
    }

    public void setCreateSerialNo(String createSerialNo) {
        this.createSerialNo = createSerialNo;
    }

    public String getStorageType() {
        return storageType;
    }

    public void setStorageType(String storageType) {
        this.storageType = storageType;
    }

    public List<Watermark> getWatermarks() {
        return watermarks;
    }

    public void setWatermarks(List<Watermark> watermarks) {
        this.watermarks = watermarks;
    }
}

==> fasc-openapi-java-sdk-5.7.8.1125-sources.jar: com/fasc/open/api/v5_1/res/template/SignTemplateDetailRes.java <==
package com.fasc.open.api.v5_1.res.template;

import com.fasc.open.api.bean.base.BaseBean;
import com.fasc.open.api.v5_1.req.signtask.Watermark;
import com.fasc.open.api.v5_1.req.template.ApprovalInfo;

import java.util.List;

/**
 * @author Fadada
 * 2021/9/11 15:16:27
 */
public class SignTemplateDetailRes extends BaseBean {
    private String signTemplateId;
    private String signTemplateName;
    private String businessTypeName;
    private String signTemplateStatus;
    private String certCAOrg;
    private Boolean signInOrder;
    private List<DocumentInfo> docs;
    private List<AttachInfo> attachs;
    private List<SignTaskActorInfo> actors;
    private String catalogName;
    private String creatorMemberName ;
    private String createSerialNo;
    private String storageType;
    private Integer effectiveDuration;
    private Boolean autoFillFinalize;
    private List<Watermark> watermarks;
    private List<ApprovalInfo> approvalInfos ;
    private String description;


    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getEffectiveDuration() {
        return effectiveDuration;
    }

    public void setEffectiveDuration(Integer effectiveDuration) {
        this.effectiveDuration = effectiveDuration;
    }

    public Boolean getAutoFillFinalize() {
        return autoFillFinalize;
    }

    public void setAutoFillFinalize(Boolean autoFillFinalize) {
        this.autoFillFinalize = autoFillFinalize;
    }

    public String getCreatorMemberName() {
        return creatorMemberName;
    }

    public void setCreatorMemberName(String creatorMemberName) {
        this.creatorMemberName = creatorMemberName;
    }

    public List<ApprovalInfo> getApprovalInfos() {
        return approvalInfos;
    }

    public void setApprovalInfos(List<ApprovalInfo> approvalInfos) {
        this.approvalInfos = approvalInfos;
    }

    public String getBusinessTypeName() {
        return businessTypeName;
    }

    public void setBusinessTypeName(String businessTypeName) {
        this.businessTypeName = businessTypeName;
    }

    public String getSignTemplateId() {
        return signTemplateId;
    }

    public void setSignTemplateId(String signTemplateId) {
        this.signTemplateId = signTemplateId;
    }

    public String getSignTemplateName() {
        return signTemplateName;
    }

    public void setSignTemplateName(String signTemplateName) {
        this.signTemplateName = signTemplateName;
    }

    public String getSignTemplateStatus() {
        return signTemplateStatus;
    }

    public void setSignTemplateStatus(String signTemplateStatus) {
        this.signTemplateStatus = signTemplateStatus;
    }

    public List<DocumentInfo> getDocs() {
        return docs;
    }

    public void setDocs(List<DocumentInfo> docs) {
        this.docs = docs;
    }

    public Boolean getSignInOrder() {
        return signInOrder;
    }

    public void setSignInOrder(Boolean signInOrder) {
        this.signInOrder = signInOrder;
    }

    public List<SignTaskActorInfo> getActors() {
        return actors;
    }

    public void setActors(List<SignTaskActorInfo> actors) {
        this.actors = actors;
    }

    public List<AttachInfo> getAttachs() {
        return attachs;
    }

    public void setAttachs(List<AttachInfo> attachs) {
        this.attachs = attachs;
    }

    public String getCertCAOrg() {
        return certCAOrg;
    }

    public void setCertCAOrg(String certCAOrg) {
        this.certCAOrg = certCAOrg;
    }

    public String getCatalogName() {
        return catalogName;
    }

    public void setCatalogName(String catalogName) {
        this.catalogName = catalogName;
    }

    public String getCreateSerialNo() {
        return createSerialNo;
    }

    public void setCreateSerialNo(String createSerialNo) {
        this.createSerialNo = createSerialNo;
    }

    public String getStorageType() {
        return storageType;
    }

    public void setStorageType(String storageType) {
        this.storageType = storageType;
    }

    public List<Watermark> getWatermarks() {
        return watermarks;
    }

    public void setWatermarks(List<Watermark> watermarks) {
        this.watermarks = watermarks;
    }
}
